@@ -24,7 +24,6 @@ from pandas._typing import CompressionOptions, StorageOptions
 
 from . import DataFrame
 from modin.config import IsExperimental, Engine
-from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
 from ...pandas import _update_engine
 
 
@@ -96,9 +95,13 @@ def read_sql(
     -------
     modin.DataFrame
     """
-    Engine.subscribe(_update_engine)
-    assert IsExperimental.get(), "This only works in experimental mode"
     _, _, _, kwargs = inspect.getargvalues(inspect.currentframe())
+
+    Engine.subscribe(_update_engine)
+    from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
+
+    assert IsExperimental.get(), "This only works in experimental mode"
+
     return DataFrame(query_compiler=FactoryDispatcher.read_sql(**kwargs))
 
 
@@ -137,9 +140,13 @@ def read_custom_text(
     -------
     modin.DataFrame
     """
-    Engine.subscribe(_update_engine)
-    assert IsExperimental.get(), "This only works in experimental mode"
     _, _, _, kwargs = inspect.getargvalues(inspect.currentframe())
+
+    Engine.subscribe(_update_engine)
+    from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
+
+    assert IsExperimental.get(), "This only works in experimental mode"
+
     return DataFrame(query_compiler=FactoryDispatcher.read_custom_text(**kwargs))
 
 
@@ -246,7 +253,7 @@ def _read(**kwargs) -> DataFrame:
     Examples
     --------
     >>> import modin.experimental.pandas as pd
-    >>> df = pd.read_csv_glob("s3://nyc-tlc/trip data/yellow_tripdata_2020-1*")
+    >>> df = pd.read_csv_glob("s3://dask-data/nyc-taxi/2015/yellow_tripdata_2015-1*")
     UserWarning: `read_*` implementation has mismatches with pandas:
     Data types of partitions are different! Please refer to the troubleshooting section of the Modin documentation to fix this issue.
             VendorID tpep_pickup_datetime  ... total_amount  congestion_surcharge
@@ -265,6 +272,7 @@ def _read(**kwargs) -> DataFrame:
     [4652013 rows x 18 columns]
     """
     Engine.subscribe(_update_engine)
+    from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
 
     try:
         pd_obj = FactoryDispatcher.read_csv_glob(**kwargs)
@@ -322,9 +330,13 @@ def read_pickle_distributed(
     -----
     The number of partitions is equal to the number of input files.
     """
-    Engine.subscribe(_update_engine)
-    assert IsExperimental.get(), "This only works in experimental mode"
     _, _, _, kwargs = inspect.getargvalues(inspect.currentframe())
+
+    Engine.subscribe(_update_engine)
+    from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
+
+    assert IsExperimental.get(), "This only works in experimental mode"
+
     return DataFrame(query_compiler=FactoryDispatcher.read_pickle_distributed(**kwargs))
 
 
@@ -357,10 +369,9 @@ def to_pickle_distributed(
         passed as additional compression options.
     protocol : int, default: pickle.HIGHEST_PROTOCOL
         Int which indicates which protocol should be used by the pickler,
-        default HIGHEST_PROTOCOL (see [1]_ paragraph 12.1.2). The possible
-        values are 0, 1, 2, 3, 4, 5. A negative value for the protocol
-        parameter is equivalent to setting its value to HIGHEST_PROTOCOL.
-        .. [1] https://docs.python.org/3/library/pickle.html.
+        default HIGHEST_PROTOCOL (see `pickle docs <https://docs.python.org/3/library/pickle.html>`_
+        paragraph 12.1.2 for details). The possible  values are 0, 1, 2, 3, 4, 5. A negative value
+        for the protocol parameter is equivalent to setting its value to HIGHEST_PROTOCOL.
     storage_options : dict, optional
         Extra options that make sense for a particular storage connection, e.g.
         host, port, username, password, etc., if using a URL that will be parsed by
@@ -370,6 +381,8 @@ def to_pickle_distributed(
     """
     obj = self
     Engine.subscribe(_update_engine)
+    from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
+
     if isinstance(self, DataFrame):
         obj = self._query_compiler
     FactoryDispatcher.to_pickle_distributed(
